LingPy's Color Model for Sound Classes

color | sound class | description | examples
--- | --- | ---
#c86464 | V | all vowels and diphthongs | a e i o u
#c89664 | K | affricates, uvulars, and velars | k g t ts
#c8c864 | P | bilabials and labiodentals | p f pf
#96c864 | H | glottals sounds | h ʔ
#64c864 | J | palatal glides | j, ɥ, ɰ
#64c896 | M | bilabial nasals | m, ɱ
#64c8c8 | N | nasals | n, ŋ 
#6496c8 | S | sibilant fricatives | s z ʃ ʒ
#6464c8 | R | r-sounds and l-sounds | r l
#9664c8 | T | dental and alveolar stops | t d
#c864c8 | W | labial glide | w v
#c86496 | 1 | any tone | ¹¹, ²²
#bbbbbb | - | markers |  +
